@@ -1,3 +1,29 @@
+#' Pipe operator
+#'
+#' See \code{\link[magrittr]{\%T>\%}} for more details.
+#'
+#' @name %T>%
+#' @rdname pipe
+#' @keywords internal
+#' @export
+#' @importFrom magrittr %T>%
+#' @usage lhs \%T>\% rhs
+NULL
+
+
+#' Pipe operator
+#'
+#' See \code{\link[magrittr]{\%>\%}} for more details.
+#'
+#' @name %>%
+#' @rdname pipe
+#' @keywords internal
+#' @export
+#' @importFrom magrittr %>%
+#' @usage lhs \%>\% rhs
+NULL
+
+
 #' Arrange multiple grobs on a page
 #'
 #' See \code{\link[gridExtra]{grid.arrange}} for more details.
