@@ -2,7 +2,8 @@
 #'
 #' Plot variable importance scores for the predictors in a model.
 #'
-#' @param object A fitted model object (e.g., a \code{"randomForest"} object).
+#' @param object A fitted model object (e.g., a \code{"randomForest"} object) or
+#' an object that inherits from class \code{"vi"}.
 #'
 #' @param num_features Integer specifying the number of variable importance
 #' scores to plot. Default is \code{10}.
@@ -48,10 +49,20 @@
 #' data(mtcars)
 #'
 #' # Fit a projection pursuit regression model
-#' mtcars.ppr <- ppr(mpg ~ ., data = mtcars, nterms = 1)
+#' model <- ppr(mpg ~ ., data = mtcars, nterms = 1)
 #'
 #' # Construct variable importance plot
-#' vip(mtcars.ppr, method = "ice")
+#' vip(model, method = "ice")
+#'
+#' # Better yet, store the variable importance scores and then plot
+#' vi_scores <- vi(model, method = "ice")
+#' vip(vi_scores, bar = FALSE, size = 3, horiz = FALSE)
+#'
+#' # The \code{\link[magrittr]{\%T>\%}} operator is imported for convenience
+#' vi_scores <- model %>%
+#'   vi(method = "ice") %T>%
+#'   {print(vip(.))}
+#' vi_scores
 vip <- function(object, ...) {
   UseMethod("vip")
 }
@@ -64,7 +75,11 @@ vip.default <- function(
   object, num_features = 10L, bar = TRUE, width = 0.75, horizontal = TRUE,
   alpha = 1, color = "grey35", fill = "grey35", size = 1, shape = 19, ...
 ) {
-  imp <- vi(object, ...)  # variable importance scores
+  imp <- if (inherits(object, what = "vi")) {
+    object
+  } else {
+    vi(object, ...)  # compute variable importance scores
+  }
   vi_type <- attr(imp, which = "type")  # subsetting removes this attribute!
   num_features <- as.integer(num_features)[1L]  # make sure num_features is a single integer
   if (num_features > nrow(imp) || num_features < 1L) {
@@ -74,13 +89,25 @@ vip.default <- function(
   x.string <- "reorder(Variable, Importance)"
   p <- ggplot2::ggplot(imp, ggplot2::aes_string(x = x.string, y = "Importance"))
   p <- if (bar) {
-    p + ggplot2::geom_col(
-      width = width, color = color, fill = fill, alpha = alpha
-    )
+    if ("Sign" %in% names(imp)) {
+      p + ggplot2::geom_col(ggplot2::aes_string(color = "Sign", fill = "Sign"),
+                            width = width, alpha = alpha
+      )
+    } else {
+      p + ggplot2::geom_col(
+        width = width, color = color, fill = fill, alpha = alpha
+      )
+    }
   } else {
-    p + ggplot2::geom_point(
-      color = color, alpha = alpha, size = size, shape = shape
-    )
+    if ("Sign" %in% names(imp)) {
+      p + ggplot2::geom_point(ggplot2::aes_string(color = "Sign"),
+                              alpha = alpha, size = size, shape = shape
+      )
+    } else {
+      p + ggplot2::geom_point(
+        color = color, alpha = alpha, size = size, shape = shape
+      )
+    }
   }
   p <- p + ggplot2::theme(legend.position = "none")
   p <- p + ggplot2::xlab("")  # no need for x-axis label
